@@ -209,4 +209,7 @@ class _ElementKeywords(KeywordGroup):
         if first_only:
             if len(elements) == 0: return None
             return elements[0]
-        return elements
\ No newline at end of file
+        return elements
+
+    def _is_text_present(self, text):
+        return text in self.get_source()
\ No newline at end of file
